@@ -18,7 +18,7 @@
 //
 //  You should have received a copy of the GNU General Public License
 //  along with this program; if not, write to the Free Software
-//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 //
 
 #ifdef HAVE_CONFIG_H
@@ -36,7 +36,7 @@
 
 static const char description[] = I18N_NOOP("KDE note taking utility");
 
-static const char version[] = "v0.6";
+static const char version[] = "v0.7";
 
 
 int main( int argc, char **argv )
@@ -45,7 +45,7 @@ int main( int argc, char **argv )
     version, description, KAboutData::License_GPL,
     "(c) 1997-2002, Christoph Neerfeld");
   aboutData.addAuthor("Jaison Lee", I18N_NOOP("Current maintainer"), "lee.jaison@gmail.com");
-  aboutData.addAuthor("Aaron J. Seigo", 0, "aseigo@olympusproject.org");
+  aboutData.addAuthor("Aaron J. Seigo", 0, "aseigo@kde.org");
   aboutData.addAuthor("Stanislav Kljuhhin", 0, "crz@starman.ee");
   aboutData.addAuthor("Christoph Neerfeld", I18N_NOOP("Original author"), "chris@kde.org");
   KCmdLineArgs::init(argc, argv, &aboutData);
