@@ -9,7 +9,7 @@
  *
  * This file contains the implementation of the main laptop battery monitoring daemon
  *
- * $Id: laptop_daemon.cpp 369165 2004-12-08 01:41:46Z mueller $
+ * $Id: laptop_daemon.cpp 490596 2005-12-22 13:05:45Z scripty $
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include <stdlib.h>
@@ -46,7 +46,6 @@
 #include <qsocketnotifier.h>
 #include <qcursor.h>
 
-
 #include <unistd.h>
 #include <sys/time.h>
 
@@ -539,16 +538,31 @@ void laptop_daemon::haveBatteryLow(int t, const int num, const int type)
 	// notify if we must (must be last since it's synchronous)
 	if (s.notify[t]) {
             if (type) {
-                KPassivePopup::message(i18n("Battery power is running out."),
-                                       i18n("%1 % charge left.").arg(num),
-                                       BarIcon("laptop_battery"), dock_widget,
-                                       0, 20000);
+                if (s.time_based_action_critical) {
+                    KPassivePopup::message(i18n("Battery power is running out."),
+                                           i18n("%1 % charge left.").arg(num),
+                                           BarIcon("laptop_battery"), dock_widget,
+                                           0, 20000);
+                } else {
+                    // Will this ever be reached?
+                    KPassivePopup::message(i18n("Battery power is running out."),
+                                           i18n("%1 % charge left.").arg(num),
+                                           BarIcon("laptop_battery"), dock_widget,
+                                           0, 20000);
+                }
             }
             else {
-                KPassivePopup::message(i18n("Battery power is running out."),
-                                       i18n("%1 minutes left.").arg(num),
-                                       BarIcon("laptop_battery"), dock_widget,
-                                       0, 20000);
+                if (s.time_based_action_low) {
+                    KPassivePopup::message(i18n("Battery power is running out."),
+                                           i18n("1 minute left.","%n minutes left.", num),
+                                           BarIcon("laptop_battery"), dock_widget,
+                                           0, 20000);
+                } else {
+                    KPassivePopup::message(i18n("Battery power is running out."),
+                                           i18n("1% left.", "%n percent left.", num),
+                                           BarIcon("laptop_battery"), dock_widget,
+                                           0, 20000);
+                }
             }
 	}
 }
@@ -729,45 +743,67 @@ void laptop_daemon::displayPixmap()
 
 	if (dock_widget)
 		dock_widget->displayPixmap();
-
+            
 	if (left >= 0) {
-		if (!triggered[0]) {
-			if (s.exists && !powered && left <= s.low[0]) {
-				triggered[0] = 1;
-				haveBatteryLow(0, left, 0);
-			}
-		} else {
-			if (!triggered[1]) {
-				if (s.exists && !powered && left <= s.low[1]) {
-					triggered[1] = 1;
-					haveBatteryLow(1, left, 0);
-				}
-			}
-			if (left > (s.low[1]+1))
-				triggered[1] = 0;
-			if (left > s.low[0])
-				triggered[0] = 0;
-		}
-	} else
-	if (s.have_time != 1) {
-		if (!triggered[0]) {
-			if (s.exists && !powered && val <= s.low[0]) {
-				triggered[0] = 1;
-				haveBatteryLow(0, val, 1);
-			}
-		} else {
-			if (!triggered[1]) {
-				if (s.exists && !powered && val <= s.low[1]) {
-					triggered[1] = 1;
-					haveBatteryLow(1, val, 1);
-				}
-			}
-			if (val > (s.low[1]+1))
-				triggered[1] = 0;
-			if (val > s.low[0])
-				triggered[0] = 0;
-		}
-	}
+            if (!triggered[0]) {
+                if (s.time_based_action_low) {
+                    if (s.exists && !powered && left <= s.low[0]) {
+                        triggered[0] = 1;
+                        haveBatteryLow(0, left, 0);
+                    }
+                } else {
+                    if (s.exists && !powered && val <= s.low[1]) {
+                        triggered[0] = 1;
+                        haveBatteryLow(0, val, 0);
+                    }
+                }
+            }
+            if (!triggered[1]) {
+                if (s.time_based_action_critical) {
+                    if (s.exists && !powered && left <= s.low[2]) {
+                        triggered[1] = 1;
+                        haveBatteryLow(1, left, 0);
+                    }
+                } else {
+                    if (s.exists && !powered && val <= s.low[3]) {
+                        triggered[1] = 1;
+                        haveBatteryLow(1, val, 0);
+                    }
+                }
+            }
+        }
+
+        if (s.time_based_action_low || s.time_based_action_critical) {
+            if (left > (s.low[2]+1))
+                triggered[1] = 0;
+            if (left > s.low[0])
+                triggered[0] = 0;
+        } else {
+            if (val > (s.low[3]+1))
+                triggered[1] = 0;
+            if (val > s.low[1])
+                triggered[0] = 0;
+        }
+
+        if (s.have_time != 1) {
+            if (!triggered[0]) {
+                if (s.exists && !powered && val <= s.low[0]) {
+                    triggered[0] = 1;
+                    haveBatteryLow(0, val, 1);
+                }
+            } else {
+                if (!triggered[1]) {
+                    if (s.exists && !powered && val <= s.low[1]) {
+                        triggered[1] = 1;
+                        haveBatteryLow(1, val, 1);
+                    }
+                }
+                if (val > (s.low[1]+1))
+                    triggered[1] = 0;
+                if (val > s.low[0])
+                    triggered[0] = 0;
+            }
+        }
 }
 
 void laptop_daemon::invokeStandby()
@@ -819,7 +855,7 @@ void laptop_daemon::invokeShutdown()
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
  */
 
