@@ -11,7 +11,7 @@
          This code may be linked against any version of the Qt toolkit
          from Troll Tech, Norway. $
 
-   $Id: kmilo_kvaio.h 277751 2004-01-08 01:48:18Z mirko $
+   $Id: kmilo_kvaio.h 431357 2005-07-04 03:57:52Z staikos $
 
    * Portions of this code are
    * (C) 2001-2002 Stelian Pop <stelian@popies.net> and
@@ -22,11 +22,20 @@
 #ifndef _KMILO_KVAIO_H_
 #define _KMILO_KVAIO_H_
 
-#include <monitor.h>
+#include <kmainwindow.h>
+#include <kglobalaccel.h>
+#include <dcopref.h>
+#include <kapplication.h>
+
+#include "kmilod.h"
+#include "monitor.h"
+#include "kmilointerface.h"
 
 class KVaio;
 
 class KMiloKVaio : public KMilo::Monitor {
+//	Q_OBJECT
+
 	public:
 		KMiloKVaio(QObject *parent, 
 			   const char *name, const QStringList&);
@@ -37,8 +46,21 @@ class KMiloKVaio : public KMilo::Monitor {
 		virtual int progress() const;
 
 		virtual void reconfigure(KConfig*);
+
+
+		bool showTextMsg(const QString& msg) {
+		    _interface->displayText(msg); 
+		    return true;
+		}
+		bool showProgressMsg(const QString& msg, int progress) {
+		    _interface->displayProgress(msg,progress);
+		    return true;
+		}
+
 	private:
 		KVaio *m_kvaio;
+		Monitor::DisplayType m_displayType;
 };
 
+
 #endif
