@@ -14,8 +14,8 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston,
- *  MA  02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA  02110-1301, USA.
  */
 
 #include "ksim.h"
@@ -30,11 +30,14 @@
 #include <kaboutdata.h>
 #include <dcopclient.h>
 #include <kmessagebox.h>
+#include <kglobal.h>
+#include <klocale.h>
 
 extern "C"
 {
   KDE_EXPORT KPanelExtension *init(QWidget *parent, const QString &configFile)
   {
+    KGlobal::locale()->insertCatalogue("ksim");
     return new KSim::PanelExtension(configFile, KPanelExtension::Normal,
     KPanelExtension::About | KPanelExtension::Help |
     KPanelExtension::Preferences | KPanelExtension::ReportBug,
@@ -54,9 +57,9 @@ KSim::PanelExtension::PanelExtension(const QString &configFile,
 
   m_aboutData = new KAboutData(name, I18N_NOOP("KSim"), KSIM_VERSION_STRING,
      I18N_NOOP("A plugin based system monitor for KDE"),
-     KAboutData::License_GPL, I18N_NOOP("(C) 2001-2003 Robbie Ward"));
-
-  m_aboutData->addAuthor("Robbie Ward", I18N_NOOP("Author and Developer"),
+     KAboutData::License_GPL, I18N_NOOP("(C) 2001-2003 Robbie Ward\n(C) 2005 Reuben Sutton"));
+  m_aboutData->addAuthor("Reuben Sutton", I18N_NOOP("Maintainer"),"reuben.sutton@gmail.com");
+  m_aboutData->addAuthor("Robbie Ward", I18N_NOOP("Original Author"),
      "linuxphreak@gmx.co.uk");
   m_aboutData->addAuthor("Jason Katz-Brown", I18N_NOOP("Developer"),
      "jason@katzbrown.com");
